@@ -5,7 +5,7 @@ from timestream import DEFAULT_LOGGER
 from typing import List, Tuple
 
 DEFAULT_MAX_BATCH_SIZE = 100 # maximum set by AWS Timestream service limits
-DEFAULT_MIN_COMMON_DIMENSIONS = 3
+DEFAULT_MIN_COMMON_DIMENSIONS = 0
 
 
 class Batch:
@@ -47,10 +47,8 @@ def _batch_records_helper(
     
     indexes = [0] # indexes for all the records in the batch
     common_dimensions = records[0].dimensions
-    DEFAULT_LOGGER.info(f"COMMON DIMENSIONS{common_dimensions}")
     min_common_dimensions = min(min_common_dimensions, len(common_dimensions))
-    DEFAULT_LOGGER.info(f"MIN COMMON DIMENSION {min_common_dimensions}")
-
+    
     for i in range(1, len(records)):
         if len(indexes) >= max_batch_size:
             break
